#ifndef COLUMBUSDIALOGOPTIONS_H
#define COLUMBUSDIALOGOPTIONS_H

#include "widgets/ColumbusDialog.h"

class ColumbusDialogOptionsPrivate;

class ColumbusDialogOptions : public ColumbusDialog
{
    Q_OBJECT

public:
    explicit     ColumbusDialogOptions  (QWidget *parent = 0);
                ~ColumbusDialogOptions  ();

public slots:
    void         setController (ApplicationController *controller);

private:
    void         addToggle          (const QString &key);
    void         addOption          (const QString &key);

private slots:
    void         onToggleChanged    (bool value);
    void         onOptionChanged    (const QString &value);

private:
    ColumbusDialogOptionsPrivate *d;
};

#endif // COLUMBUSDIALOGOPTIONS_H
